function [muub,wc,bnds,tab] = mu_margin(sys,blk,opt);
%
% MU_MARGIN    -  Computes a guaranteed stab/perf robustness margin
%------------------------------------------------------------------
% PURPOSE
% This routine computes a (skew) mu upper-bound on a frequency seg-
% ment either on the imaginary axis or on the boundary of a trunca-
% ted sector.
%
% SYNOPSIS
% [muub,wc,bnds,tab] = mu_margin(sys,blk[,opt]);  
% 
% INPUT ARGUMENTS
% sys   SS-object defining the interconnection structure 
% blk   nblk-by-2 or nblk-by-3 matrix defining the structure of the        
%       uncertainty block DELTA = diag(DELTA_1,...,DELTA_nblk) :
%          blk(i,:) = [-n 0] --> DELTA_i = di*eye(n),    di is real
%          blk(i,:) = [n 0]  --> DELTA_i = di*eye(n), di is complex
%          blk(i,:) = [n n]  --> DELTA_i  full n-by-n complex block
%       A third column can be used to specify skew uncertainties :
%          blk(i,3) = 0 :  sig_max(DELTA_i) <= 1
%          blk(i,3) = 1 :  sig_max(DELTA_i) <= 1/muub
% opt   optional strutured variable with fields :
%         * trace   : trace of execution
%         * itermax : maximum number of iterations
%         * muT     : initial guess for mu (lower-bound)
%         * w0      : starting frequency point
%         * puls    : frequency segment [wmin wmax] or gridding
%         * sector  : truncated sector [alpha xi]
%         * tol     : tolerance on mu  (muub=(1+tol)*muopt) 
%         * lmi     : switch to LMI  (if lmi=1) for better accuracy  
%         * reg     : regularization parameter for real-mu problems
%                     by default 1% of complex uncertainty is added
%                     in case of convergence problems (reg=0.01)
%         * elim    : activation/desactivation  of  the pawl effect
%                     on mu which is used by default  to fasten the
%                     elimination technique.  Set this parameter to
%                     0 to get better estimates of secondary peaks.
%         * smm     : skew-mu method (iterative calls to mu.m)
%                     1 : fixed-point type algorithm
%                     2 : dichotomy search
%                     Note that this option is useless if the skew-
%                     mu upper-bound is computed by LMI approach.
%        
% OUTPUT ARGUMENTS
% muub   guaranteed mu upper-bound
% wc     critical frequency associated to the max. upper-bound
% bnds   structured variable with fields
%           bnds.w : list of frequency points
%           bnds.mu : associated upper-bounds
% tab   structured variable with fields
%           tab.seg : list of segments
%           tab.mu  : associated guaranteed upper-bounds
%
%------------------------------------------------------------------
% EXAMPLE
%
%  % generation of a 30-by-30 poorly-damped system with 57 states
%  minz=1; alpha=0;
%  while (minz>0.15) | (alpha>-0.25)
%     sys=rss(57,30,30); [om,z]=damp(sys); minz=min(z);
%     alpha=max(real(eig(sys)));
%  end;
%
%  % definition of blk and calling the routine
%  blk=[-10 0;-15 0;-5 0];
%  [mu1,wc1] = mu_margin(sys,blk);
%  
%  % computation on a sector
%  alpha=-0.05; xi=0.95*minz;
%  clear opt;  opt.sector=[alpha xi];
%  [mu2,wc2] = mu_margin(sys,blk,opt);
%
%  % skew-mu illustration
%  blk_skew = [blk [1 0 0]']; sysa=ssbal(sys/(2*mu1)); 
%  [muperf,wcp] = mu_margin(sysa,blk_skew);
% 
%
% Skew Mu Toolbox - G. Ferreres and J.M. Biannic, Onera-DCSD Toulouse, France.
%
if nargin==3
    [muub,wc,bnds,tab] = mu_marg(sys,blk,opt);
elseif nargin==2
    [muub,wc,bnds,tab] = mu_marg(sys,blk);
else
    error('Incorrect number of input arguments');
end;
    


